# Helper
A python helper for Object, String, Setting, Reflection, etc

--- 
# How to install
```
pip install python-helper
```

Stable version: `0.3.55`

---
# How to run the tests
Clone repository and install depentencies


The following block at `Tests,py`
```python
TestHelper.run(__file__)
```
will run all tests under the package `./python_helper/api/tests` (and also any package named test anywhere else, whitch is not the case)


So, basically, you can run the tests in your prompt just executing `Tests.py`
```
python Tests.py
```
